==> haskell-transformers-base-0.4.5.2-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.5.2
id: transformers-base-0.4.5.2-II2bOKw9mMZBRrynUnHtTn
key: transformers-base-0.4.5.2-II2bOKw9mMZBRrynUnHtTn
license: BSD-3-Clause
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
abi: 676f6c53dfc0a9b1b0da07d4079c21a7
exposed: True
exposed-modules:
    Control.Monad.Base
import-dirs: /usr/lib/ghc-8.6.5/site-local/transformers-base-0.4.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/transformers-base-0.4.5.2
hs-libraries: HStransformers-base-0.4.5.2-II2bOKw9mMZBRrynUnHtTn
depends:
    base-4.12.0.0 base-orphans-0.8.1-ADx13UE5kNMLP8OA0gQSRH stm-2.5.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.5.2-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.5.2
id: transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
key: transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
license: BSD-3-Clause
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
abi: 79d7c94c28caffe32125dcb1b56c1232
exposed: True
exposed-modules:
    Control.Monad.Base
import-dirs: /usr/lib/ghc-8.6.5/site-local/transformers-base-0.4.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/transformers-base-0.4.5.2
hs-libraries: HStransformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
depends:
    base-4.12.0.0 base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3 stm-2.5.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
